# StaticHessian Module

::: tdscha.StaticHessian
    options:
      show_root_heading: true
      show_source: true
      heading_level: 2
      members_order: source

## StaticHessian Class

::: tdscha.StaticHessian.StaticHessian
    options:
      heading_level: 2
      show_source: true
      members_order: source
      filters: ["!^_", "!^__"]


